# eric7.Utilities.uic

Module implementing a function to compile all user interface files of a directory or directory tree.

### Global Attributes

None

### Classes

None

### Functions

__pyName | Local function to create the Python source file name for the compiled .ui file.
compileUiFiles | Module function to compile the .ui files of a directory tree to Python sources.

## __pyName

__pyName(py_dir, py_file)

Local function to create the Python source file name for the compiled .ui file.

py_dir (str)
  suggested name of the directory
py_file (str)
  suggested name for the compiled source file

Return:
  tuple of directory name and source file name

Return Type:
  tuple of (str, str)

Up

## compileUiFiles

compileUiFiles(directory, recurse=False)

Module function to compile the .ui files of a directory tree to Python sources.

directory (str)
  name of a directory to scan for .ui files
recurse (boolean))
  flag indicating to recurse into subdirectories

Up